==> vtk-8.1.0-3-aarch64.pkg.tar.xz: vtk/vtkAxisActor2D.java <==
// java wrapper for vtkAxisActor2D object
//

package vtk;
import vtk.*;

public class vtkAxisActor2D extends vtkActor2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint1_3(double id0[]);
  public void SetPoint1(double id0[])
    { SetPoint1_3(id0); }

  private native void SetPoint1_4(double id0,double id1);
  public void SetPoint1(double id0,double id1)
    { SetPoint1_4(id0,id1); }

  private native long GetPoint2Coordinate_5();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_5();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint2_6(double id0[]);
  public void SetPoint2(double id0[])
    { SetPoint2_6(id0); }

  private native void SetPoint2_7(double id0,double id1);
  public void SetPoint2(double id0,double id1)
    { SetPoint2_7(id0,id1); }

  private native void SetRange_8(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_8(id0,id1); }

  private native void SetRange_9(double id0[]);
  public void SetRange(double id0[])
    { SetRange_9(id0); }

  private native double[] GetRange_10();
  public double[] GetRange()
    { return GetRange_10(); }

  private native void SetRulerMode_11(int id0);
  public void SetRulerMode(int id0)
    { SetRulerMode_11(id0); }

  private native int GetRulerMode_12();
  public int GetRulerMode()
    { return GetRulerMode_12(); }

  private native void RulerModeOn_13();
  public void RulerModeOn()
    { RulerModeOn_13(); }

  private native void RulerModeOff_14();
  public void RulerModeOff()
    { RulerModeOff_14(); }

  private native void SetRulerDistance_15(double id0);
  public void SetRulerDistance(double id0)
    { SetRulerDistance_15(id0); }

  private native double GetRulerDistanceMinValue_16();
  public double GetRulerDistanceMinValue()
    { return GetRulerDistanceMinValue_16(); }

  private native double GetRulerDistanceMaxValue_17();
  public double GetRulerDistanceMaxValue()
    { return GetRulerDistanceMaxValue_17(); }

  private native double GetRulerDistance_18();
  public double GetRulerDistance()
    { return GetRulerDistance_18(); }

  private native void SetNumberOfLabels_19(int id0);
  public void SetNumberOfLabels(int id0)
    { SetNumberOfLabels_19(id0); }

  private native int GetNumberOfLabelsMinValue_20();
  public int GetNumberOfLabelsMinValue()
    { return GetNumberOfLabelsMinValue_20(); }

  private native int GetNumberOfLabelsMaxValue_21();
  public int GetNumberOfLabelsMaxValue()
    { return GetNumberOfLabelsMaxValue_21(); }

  private native int GetNumberOfLabels_22();
  public int GetNumberOfLabels()
    { return GetNumberOfLabels_22(); }

  private native void SetLabelFormat_23(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_23(id0); }

  private native String GetLabelFormat_24();
  public String GetLabelFormat()
    { return GetLabelFormat_24(); }

  private native void SetAdjustLabels_25(int id0);
  public void SetAdjustLabels(int id0)
    { SetAdjustLabels_25(id0); }

  private native int GetAdjustLabels_26();
  public int GetAdjustLabels()
    { return GetAdjustLabels_26(); }

  private native void AdjustLabelsOn_27();
  public void AdjustLabelsOn()
    { AdjustLabelsOn_27(); }

  private native void AdjustLabelsOff_28();
  public void AdjustLabelsOff()
    { AdjustLabelsOff_28(); }

  private native void GetAdjustedRange_29(double id0[]);
  public void GetAdjustedRange(double id0[])
    { GetAdjustedRange_29(id0); }

  private native int GetAdjustedNumberOfLabels_30();
  public int GetAdjustedNumberOfLabels()
    { return GetAdjustedNumberOfLabels_30(); }

  private native void SetTitle_31(String id0);
  public void SetTitle(String id0)
    { SetTitle_31(id0); }

  private native String GetTitle_32();
  public String GetTitle()
    { return GetTitle_32(); }

  private native void SetTitleTextProperty_33(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_33(id0); }

  private native long GetTitleTextProperty_34();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_34();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelTextProperty_35(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_35(id0); }

  private native long GetLabelTextProperty_36();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_36();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTickLength_37(int id0);
  public void SetTickLength(int id0)
    { SetTickLength_37(id0); }

  private native int GetTickLengthMinValue_38();
  public int GetTickLengthMinValue()
    { return GetTickLengthMinValue_38(); }

  private native int GetTickLengthMaxValue_39();
  public int GetTickLengthMaxValue()
    { return GetTickLengthMaxValue_39(); }

  private native int GetTickLength_40();
  public int GetTickLength()
    { return GetTickLength_40(); }

  private native void SetNumberOfMinorTicks_41(int id0);
  public void SetNumberOfMinorTicks(int id0)
    { SetNumberOfMinorTicks_41(id0); }

  private native int GetNumberOfMinorTicksMinValue_42();
  public int GetNumberOfMinorTicksMinValue()
    { return GetNumberOfMinorTicksMinValue_42(); }

  private native int GetNumberOfMinorTicksMaxValue_43();
  public int GetNumberOfMinorTicksMaxValue()
    { return GetNumberOfMinorTicksMaxValue_43(); }

  private native int GetNumberOfMinorTicks_44();
  public int GetNumberOfMinorTicks()
    { return GetNumberOfMinorTicks_44(); }

  private native void SetMinorTickLength_45(int id0);
  public void SetMinorTickLength(int id0)
    { SetMinorTickLength_45(id0); }

  private native int GetMinorTickLengthMinValue_46();
  public int GetMinorTickLengthMinValue()
    { return GetMinorTickLengthMinValue_46(); }

  private native int GetMinorTickLengthMaxValue_47();
  public int GetMinorTickLengthMaxValue()
    { return GetMinorTickLengthMaxValue_47(); }

  private native int GetMinorTickLength_48();
  public int GetMinorTickLength()
    { return GetMinorTickLength_48(); }

  private native void SetTickOffset_49(int id0);
  public void SetTickOffset(int id0)
    { SetTickOffset_49(id0); }

  private native int GetTickOffsetMinValue_50();
  public int GetTickOffsetMinValue()
    { return GetTickOffsetMinValue_50(); }

  private native int GetTickOffsetMaxValue_51();
  public int GetTickOffsetMaxValue()
    { return GetTickOffsetMaxValue_51(); }

  private native int GetTickOffset_52();
  public int GetTickOffset()
    { return GetTickOffset_52(); }

  private native void SetAxisVisibility_53(int id0);
  public void SetAxisVisibility(int id0)
    { SetAxisVisibility_53(id0); }

  private native int GetAxisVisibility_54();
  public int GetAxisVisibility()
    { return GetAxisVisibility_54(); }

  private native void AxisVisibilityOn_55();
  public void AxisVisibilityOn()
    { AxisVisibilityOn_55(); }

  private native void AxisVisibilityOff_56();
  public void AxisVisibilityOff()
    { AxisVisibilityOff_56(); }

  private native void SetTickVisibility_57(int id0);
  public void SetTickVisibility(int id0)
    { SetTickVisibility_57(id0); }

  private native int GetTickVisibility_58();
  public int GetTickVisibility()
    { return GetTickVisibility_58(); }

  private native void TickVisibilityOn_59();
  public void TickVisibilityOn()
    { TickVisibilityOn_59(); }

  private native void TickVisibilityOff_60();
  public void TickVisibilityOff()
    { TickVisibilityOff_60(); }

  private native void SetLabelVisibility_61(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_61(id0); }

  private native int GetLabelVisibility_62();
  public int GetLabelVisibility()
    { return GetLabelVisibility_62(); }

  private native void LabelVisibilityOn_63();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_63(); }

  private native void LabelVisibilityOff_64();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_64(); }

  private native void SetTitleVisibility_65(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_65(id0); }

  private native int GetTitleVisibility_66();
  public int GetTitleVisibility()
    { return GetTitleVisibility_66(); }

  private native void TitleVisibilityOn_67();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_67(); }

  private native void TitleVisibilityOff_68();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_68(); }

  private native void SetTitlePosition_69(double id0);
  public void SetTitlePosition(double id0)
    { SetTitlePosition_69(id0); }

  private native double GetTitlePosition_70();
  public double GetTitlePosition()
    { return GetTitlePosition_70(); }

  private native void SetFontFactor_71(double id0);
  public void SetFontFactor(double id0)
    { SetFontFactor_71(id0); }

  private native double GetFontFactorMinValue_72();
  public double GetFontFactorMinValue()
    { return GetFontFactorMinValue_72(); }

  private native double GetFontFactorMaxValue_73();
  public double GetFontFactorMaxValue()
    { return GetFontFactorMaxValue_73(); }

  private native double GetFontFactor_74();
  public double GetFontFactor()
    { return GetFontFactor_74(); }

  private native void SetLabelFactor_75(double id0);
  public void SetLabelFactor(double id0)
    { SetLabelFactor_75(id0); }

  private native double GetLabelFactorMinValue_76();
  public double GetLabelFactorMinValue()
    { return GetLabelFactorMinValue_76(); }

  private native double GetLabelFactorMaxValue_77();
  public double GetLabelFactorMaxValue()
    { return GetLabelFactorMaxValue_77(); }

  private native double GetLabelFactor_78();
  public double GetLabelFactor()
    { return GetLabelFactor_78(); }

  private native int RenderOverlay_79(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_79(id0); }

  private native int RenderOpaqueGeometry_80(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_80(id0); }

  private native int RenderTranslucentPolygonalGeometry_81(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_81(id0); }

  private native int HasTranslucentPolygonalGeometry_82();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_82(); }

  private native void ReleaseGraphicsResources_83(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_83(id0); }

  private native void SetSizeFontRelativeToAxis_84(int id0);
  public void SetSizeFontRelativeToAxis(int id0)
    { SetSizeFontRelativeToAxis_84(id0); }

  private native int GetSizeFontRelativeToAxis_85();
  public int GetSizeFontRelativeToAxis()
    { return GetSizeFontRelativeToAxis_85(); }

  private native void SizeFontRelativeToAxisOn_86();
  public void SizeFontRelativeToAxisOn()
    { SizeFontRelativeToAxisOn_86(); }

  private native void SizeFontRelativeToAxisOff_87();
  public void SizeFontRelativeToAxisOff()
    { SizeFontRelativeToAxisOff_87(); }

  private native void ShallowCopy_88(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_88(id0); }

  public vtkAxisActor2D() { super(); }

  public vtkAxisActor2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkAxisActor2D.java <==
// java wrapper for vtkAxisActor2D object
//

package vtk;
import vtk.*;

public class vtkAxisActor2D extends vtkActor2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint1_3(double id0[]);
  public void SetPoint1(double id0[])
    { SetPoint1_3(id0); }

  private native void SetPoint1_4(double id0,double id1);
  public void SetPoint1(double id0,double id1)
    { SetPoint1_4(id0,id1); }

  private native long GetPoint2Coordinate_5();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_5();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint2_6(double id0[]);
  public void SetPoint2(double id0[])
    { SetPoint2_6(id0); }

  private native void SetPoint2_7(double id0,double id1);
  public void SetPoint2(double id0,double id1)
    { SetPoint2_7(id0,id1); }

  private native void SetRange_8(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_8(id0,id1); }

  private native void SetRange_9(double id0[]);
  public void SetRange(double id0[])
    { SetRange_9(id0); }

  private native double[] GetRange_10();
  public double[] GetRange()
    { return GetRange_10(); }

  private native void SetRulerMode_11(int id0);
  public void SetRulerMode(int id0)
    { SetRulerMode_11(id0); }

  private native int GetRulerMode_12();
  public int GetRulerMode()
    { return GetRulerMode_12(); }

  private native void RulerModeOn_13();
  public void RulerModeOn()
    { RulerModeOn_13(); }

  private native void RulerModeOff_14();
  public void RulerModeOff()
    { RulerModeOff_14(); }

  private native void SetRulerDistance_15(double id0);
  public void SetRulerDistance(double id0)
    { SetRulerDistance_15(id0); }

  private native double GetRulerDistanceMinValue_16();
  public double GetRulerDistanceMinValue()
    { return GetRulerDistanceMinValue_16(); }

  private native double GetRulerDistanceMaxValue_17();
  public double GetRulerDistanceMaxValue()
    { return GetRulerDistanceMaxValue_17(); }

  private native double GetRulerDistance_18();
  public double GetRulerDistance()
    { return GetRulerDistance_18(); }

  private native void SetNumberOfLabels_19(int id0);
  public void SetNumberOfLabels(int id0)
    { SetNumberOfLabels_19(id0); }

  private native int GetNumberOfLabelsMinValue_20();
  public int GetNumberOfLabelsMinValue()
    { return GetNumberOfLabelsMinValue_20(); }

  private native int GetNumberOfLabelsMaxValue_21();
  public int GetNumberOfLabelsMaxValue()
    { return GetNumberOfLabelsMaxValue_21(); }

  private native int GetNumberOfLabels_22();
  public int GetNumberOfLabels()
    { return GetNumberOfLabels_22(); }

  private native void SetLabelFormat_23(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_23(id0); }

  private native String GetLabelFormat_24();
  public String GetLabelFormat()
    { return GetLabelFormat_24(); }

  private native void SetAdjustLabels_25(int id0);
  public void SetAdjustLabels(int id0)
    { SetAdjustLabels_25(id0); }

  private native int GetAdjustLabels_26();
  public int GetAdjustLabels()
    { return GetAdjustLabels_26(); }

  private native void AdjustLabelsOn_27();
  public void AdjustLabelsOn()
    { AdjustLabelsOn_27(); }

  private native void AdjustLabelsOff_28();
  public void AdjustLabelsOff()
    { AdjustLabelsOff_28(); }

  private native void GetAdjustedRange_29(double id0[]);
  public void GetAdjustedRange(double id0[])
    { GetAdjustedRange_29(id0); }

  private native int GetAdjustedNumberOfLabels_30();
  public int GetAdjustedNumberOfLabels()
    { return GetAdjustedNumberOfLabels_30(); }

  private native void SetTitle_31(String id0);
  public void SetTitle(String id0)
    { SetTitle_31(id0); }

  private native String GetTitle_32();
  public String GetTitle()
    { return GetTitle_32(); }

  private native void SetTitleTextProperty_33(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_33(id0); }

  private native long GetTitleTextProperty_34();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_34();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelTextProperty_35(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_35(id0); }

  private native long GetLabelTextProperty_36();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_36();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTickLength_37(int id0);
  public void SetTickLength(int id0)
    { SetTickLength_37(id0); }

  private native int GetTickLengthMinValue_38();
  public int GetTickLengthMinValue()
    { return GetTickLengthMinValue_38(); }

  private native int GetTickLengthMaxValue_39();
  public int GetTickLengthMaxValue()
    { return GetTickLengthMaxValue_39(); }

  private native int GetTickLength_40();
  public int GetTickLength()
    { return GetTickLength_40(); }

  private native void SetNumberOfMinorTicks_41(int id0);
  public void SetNumberOfMinorTicks(int id0)
    { SetNumberOfMinorTicks_41(id0); }

  private native int GetNumberOfMinorTicksMinValue_42();
  public int GetNumberOfMinorTicksMinValue()
    { return GetNumberOfMinorTicksMinValue_42(); }

  private native int GetNumberOfMinorTicksMaxValue_43();
  public int GetNumberOfMinorTicksMaxValue()
    { return GetNumberOfMinorTicksMaxValue_43(); }

  private native int GetNumberOfMinorTicks_44();
  public int GetNumberOfMinorTicks()
    { return GetNumberOfMinorTicks_44(); }

  private native void SetMinorTickLength_45(int id0);
  public void SetMinorTickLength(int id0)
    { SetMinorTickLength_45(id0); }

  private native int GetMinorTickLengthMinValue_46();
  public int GetMinorTickLengthMinValue()
    { return GetMinorTickLengthMinValue_46(); }

  private native int GetMinorTickLengthMaxValue_47();
  public int GetMinorTickLengthMaxValue()
    { return GetMinorTickLengthMaxValue_47(); }

  private native int GetMinorTickLength_48();
  public int GetMinorTickLength()
    { return GetMinorTickLength_48(); }

  private native void SetTickOffset_49(int id0);
  public void SetTickOffset(int id0)
    { SetTickOffset_49(id0); }

  private native int GetTickOffsetMinValue_50();
  public int GetTickOffsetMinValue()
    { return GetTickOffsetMinValue_50(); }

  private native int GetTickOffsetMaxValue_51();
  public int GetTickOffsetMaxValue()
    { return GetTickOffsetMaxValue_51(); }

  private native int GetTickOffset_52();
  public int GetTickOffset()
    { return GetTickOffset_52(); }

  private native void SetAxisVisibility_53(int id0);
  public void SetAxisVisibility(int id0)
    { SetAxisVisibility_53(id0); }

  private native int GetAxisVisibility_54();
  public int GetAxisVisibility()
    { return GetAxisVisibility_54(); }

  private native void AxisVisibilityOn_55();
  public void AxisVisibilityOn()
    { AxisVisibilityOn_55(); }

  private native void AxisVisibilityOff_56();
  public void AxisVisibilityOff()
    { AxisVisibilityOff_56(); }

  private native void SetTickVisibility_57(int id0);
  public void SetTickVisibility(int id0)
    { SetTickVisibility_57(id0); }

  private native int GetTickVisibility_58();
  public int GetTickVisibility()
    { return GetTickVisibility_58(); }

  private native void TickVisibilityOn_59();
  public void TickVisibilityOn()
    { TickVisibilityOn_59(); }

  private native void TickVisibilityOff_60();
  public void TickVisibilityOff()
    { TickVisibilityOff_60(); }

  private native void SetLabelVisibility_61(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_61(id0); }

  private native int GetLabelVisibility_62();
  public int GetLabelVisibility()
    { return GetLabelVisibility_62(); }

  private native void LabelVisibilityOn_63();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_63(); }

  private native void LabelVisibilityOff_64();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_64(); }

  private native void SetTitleVisibility_65(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_65(id0); }

  private native int GetTitleVisibility_66();
  public int GetTitleVisibility()
    { return GetTitleVisibility_66(); }

  private native void TitleVisibilityOn_67();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_67(); }

  private native void TitleVisibilityOff_68();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_68(); }

  private native void SetTitlePosition_69(double id0);
  public void SetTitlePosition(double id0)
    { SetTitlePosition_69(id0); }

  private native double GetTitlePosition_70();
  public double GetTitlePosition()
    { return GetTitlePosition_70(); }

  private native void SetFontFactor_71(double id0);
  public void SetFontFactor(double id0)
    { SetFontFactor_71(id0); }

  private native double GetFontFactorMinValue_72();
  public double GetFontFactorMinValue()
    { return GetFontFactorMinValue_72(); }

  private native double GetFontFactorMaxValue_73();
  public double GetFontFactorMaxValue()
    { return GetFontFactorMaxValue_73(); }

  private native double GetFontFactor_74();
  public double GetFontFactor()
    { return GetFontFactor_74(); }

  private native void SetLabelFactor_75(double id0);
  public void SetLabelFactor(double id0)
    { SetLabelFactor_75(id0); }

  private native double GetLabelFactorMinValue_76();
  public double GetLabelFactorMinValue()
    { return GetLabelFactorMinValue_76(); }

  private native double GetLabelFactorMaxValue_77();
  public double GetLabelFactorMaxValue()
    { return GetLabelFactorMaxValue_77(); }

  private native double GetLabelFactor_78();
  public double GetLabelFactor()
    { return GetLabelFactor_78(); }

  private native int RenderOverlay_79(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_79(id0); }

  private native int RenderOpaqueGeometry_80(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_80(id0); }

  private native int RenderTranslucentPolygonalGeometry_81(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_81(id0); }

  private native int HasTranslucentPolygonalGeometry_82();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_82(); }

  private native void ReleaseGraphicsResources_83(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_83(id0); }

  private native void SetSizeFontRelativeToAxis_84(int id0);
  public void SetSizeFontRelativeToAxis(int id0)
    { SetSizeFontRelativeToAxis_84(id0); }

  private native int GetSizeFontRelativeToAxis_85();
  public int GetSizeFontRelativeToAxis()
    { return GetSizeFontRelativeToAxis_85(); }

  private native void SizeFontRelativeToAxisOn_86();
  public void SizeFontRelativeToAxisOn()
    { SizeFontRelativeToAxisOn_86(); }

  private native void SizeFontRelativeToAxisOff_87();
  public void SizeFontRelativeToAxisOff()
    { SizeFontRelativeToAxisOff_87(); }

  private native void SetUseFontSizeFromProperty_88(int id0);
  public void SetUseFontSizeFromProperty(int id0)
    { SetUseFontSizeFromProperty_88(id0); }

  private native int GetUseFontSizeFromProperty_89();
  public int GetUseFontSizeFromProperty()
    { return GetUseFontSizeFromProperty_89(); }

  private native void UseFontSizeFromPropertyOn_90();
  public void UseFontSizeFromPropertyOn()
    { UseFontSizeFromPropertyOn_90(); }

  private native void UseFontSizeFromPropertyOff_91();
  public void UseFontSizeFromPropertyOff()
    { UseFontSizeFromPropertyOff_91(); }

  private native void ShallowCopy_92(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_92(id0); }

  public vtkAxisActor2D() { super(); }

  public vtkAxisActor2D(long id) { super(id); }
  public native long   VTKInit();

}
